.. _contributing:

Contributing
============

Contributions and suggestions to this package are very welcome.

If you think you have found a bug, please raise an issue on GitHub, providing information about what you were trying to do, the function/script you ran, the error message/output and your ``matador`` version. If you are able to, please try to replicate the problem on the ``master`` branch before posting.

If you have a feature request, or you would like to contribute a feature, please raise an issue so that its suitability for this package can be discussed. Ideally, you could do this before writing your implementation, as the feature may already exist! Code contributions must include tests for any new functionality and must pass existing tests and ``flake8`` linting run by the CI. Any new modules must use the ``black`` auto-formatter.
